import { arch, platform } from 'node:process'

export const getBinaryPath = async (): Promise<string | null> => {
  const hostPackage = `@netlify/local-functions-proxy-${platform}-${arch}`

  try {
    const {
      default: { optionalDependencies },
    } = await import('./package.json', { with: { type: 'json' } })

    if (!(hostPackage in optionalDependencies)) {
      return null
    }

    // eslint-disable-next-line import/no-dynamic-require
    const { binaryPath } = await import(hostPackage)

    return binaryPath
  } catch (error) {
    console.error(`Could not load ${hostPackage}:`, error instanceof Error ? error.message : error?.toString())

    return null
  }
}
